@@ -17,7 +17,9 @@ from pysegmenters_pysdb.pysbd_sentencizer import PySBDSentencizer
 
 class PySDBSegmenterParameters(SegmenterParameters, ProcessorParameters, ABC):
     language: str = Field("xx",
-                          description="Name of the 2-letter language to use if the language of the document is not set", extra="language")
+                          description=""
+                                      ""
+                                      "Language to use if the language of the document is not set", extra="language")
 
 
 class PySDBSegmenter(SegmenterBase, ProcessorBase, ABC):
